onPlaybackSpeedChanged property
Called with the next speed value when the user taps the speed button. Cycles: 1.0 → 1.5 → 2.0 → 1.0
Implementation
final ValueChanged<double>? onPlaybackSpeedChanged;
Called with the next speed value when the user taps the speed button. Cycles: 1.0 → 1.5 → 2.0 → 1.0
final ValueChanged<double>? onPlaybackSpeedChanged;