groupingThreshold property

Duration groupingThreshold
final

Maximum time gap between two consecutive messages from the same sender before they are split into separate groups. Defaults to 1 minute.

Implementation

final Duration groupingThreshold;