timestampOf property

DateTime? Function(int index)? timestampOf
final

Optional: returns the send timestamp for the message at index. Used to break groups when a time gap exceeds groupingThreshold.

Implementation

final DateTime? Function(int index)? timestampOf;