showAvatar property
Whether an avatar should be shown beside this bubble. True when isGroupEnd or isAlone.
Implementation
final bool showAvatar;
Whether an avatar should be shown beside this bubble. True when isGroupEnd or isAlone.
final bool showAvatar;