GroupInfo class
Grouping information for a single message within a consecutive sender block.
Use the values from this class to control how each bubble is rendered:
- Pass showTail to the bubble's
tailparameter - Show an avatar widget only when showAvatar is true
- Add extra top spacing when isGroupStart is true
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAlone → bool
-
Whether this is the only message from this sender in this block
final
- isGroupEnd → bool
-
Whether this is the last message in the block (tail should be shown)
final
- isGroupStart → bool
-
Whether this is the first message in a consecutive block from the same sender
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAvatar → bool
-
Whether an avatar should be shown beside this bubble.
True when isGroupEnd or isAlone.
final
- showTail → bool
-
Convenience alias for isGroupEnd — pass this to the bubble's
tailparamfinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited