MessageBarStyle class
Style configuration for a MessageBar.
Groups commonly used appearance and input properties such as borders, padding, keyboard type, and background color.
Constructors
- MessageBarStyle({InputBorder enabledBorder = const OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(30)), borderSide: BorderSide(color: Colors.white, width: 0.2)), InputBorder focusedBorder = const OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(30)), borderSide: BorderSide(color: Colors.black26, width: 0.2)), TextInputType keyboardType = TextInputType.multiline, TextCapitalization textCapitalization = TextCapitalization.sentences, EdgeInsetsGeometry contentPadding = const EdgeInsets.symmetric(horizontal: 8.0, vertical: 10), Color fillColor = Colors.white, int minLines = 1, int maxLines = 3})
-
Creates a
MessageBarStyle.const
Properties
- contentPadding → EdgeInsetsGeometry
-
Inner padding of the input field.
final
- enabledBorder → InputBorder
-
Border when the input is enabled but not focused.
final
- fillColor → Color
-
Background color of the input field.
final
- focusedBorder → InputBorder
-
Border when the input is focused.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyboardType → TextInputType
-
Keyboard type for the input field.
final
- maxLines → int
-
maximum number of lines of the input field.
final
- minLines → int
-
minimum number of lines of the input field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textCapitalization → TextCapitalization
-
Text capitalization behavior.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited